@@ -534,11 +534,11 @@ void samplv1_lv2::qapp_instantiate (void)
 	if (qApp == nullptr && g_qapp_instance == nullptr) {
 		static int s_argc = 1;
 		static const char *s_argv[] = { SAMPLV1_TITLE, nullptr };
+		::setenv("QT_NO_GLIB", "1", 1); // Avoid glib event-loop...
 		g_qapp_instance = new QApplication(s_argc, (char **) s_argv);
 	}
 
-	if (g_qapp_instance)
-		g_qapp_refcount++;
+	if (g_qapp_instance) ++g_qapp_refcount;
 }
 
 
