@@ -1,7 +1,7 @@
 // samplv1_lv2.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -91,13 +91,28 @@ public:
 protected:
 
 	void updatePreset(bool bDirty);
+	void updateParam(samplv1::ParamIndex index);
+	void updateParams();
+
 	void updateSample();
+
+	void updateOffsetRange();
+	void updateLoopRange();
+	void updateLoopFade();
+	void updateLoopZero();
+
 	void updateTuning();
 
 	bool state_changed();
 
 #ifdef CONFIG_LV2_PATCH
-	bool patch_put(uint32_t ndelta, uint32_t type = 0);
+	bool patch_set(LV2_URID key);
+	bool patch_get(LV2_URID key);
+#endif
+
+#ifdef CONFIG_LV2_PORT_EVENT
+	bool port_event(samplv1::ParamIndex index);
+	bool port_events();
 #endif
 
 private:
@@ -135,6 +150,10 @@ private:
 		LV2_URID atom_Int;
 		LV2_URID atom_Bool;
 		LV2_URID atom_Path;
+	#ifdef CONFIG_LV2_PORT_EVENT
+		LV2_URID atom_PortEvent;
+		LV2_URID atom_portTuple;
+	#endif
 		LV2_URID time_Position;
 		LV2_URID time_beatsPerMinute;
 		LV2_URID midi_MidiEvent;
@@ -145,8 +164,6 @@ private:
 	#ifdef CONFIG_LV2_PATCH
 		LV2_URID patch_Get;
 		LV2_URID patch_Set;
-		LV2_URID patch_Put;
-		LV2_URID patch_body;
 		LV2_URID patch_property;
 		LV2_URID patch_value;
 	#endif
