@@ -128,7 +128,7 @@ samplv1widget::samplv1widget ( QWidget *pParent )
 	// Note names.
 	QStringList notes;
 	for (int note = 0; note < 128; ++note)
-		notes << samplv1_ui::noteName(note).remove(QRegExp("/\\S+"));
+		notes << samplv1_ui::noteName(note).remove(QRegularExpression("/\\S+"));
 
 	m_ui.Gen1SampleKnob->setScale(1000.0f);
 	m_ui.Gen1SampleKnob->insertItems(0, notes);
@@ -576,6 +576,11 @@ samplv1widget::samplv1widget ( QWidget *pParent )
 		SIGNAL(toggled(bool)),
 		SLOT(swapParams(bool)));
 
+	// Randomize params...
+	QObject::connect(m_ui.PanicButton,
+		SIGNAL(clicked()),
+		SLOT(panic()));
+	
 	// Direct stacked-page signal/slot
 	QObject::connect(m_ui.TabBar, SIGNAL(currentChanged(int)),
 		m_ui.StackedWidget, SLOT(setCurrentIndex(int)));
@@ -974,6 +979,15 @@ void samplv1widget::swapParams ( bool bOn )
 }
 
 
+// Panic: all-notes/sound-off (reset).
+void samplv1widget::panic (void)
+{
+	samplv1_ui *pSamplUi = ui_instance();
+	if (pSamplUi)
+		pSamplUi->reset();
+}
+
+
 // Reset swap params A/B group.
 void samplv1widget::resetSwapParams (void)
 {
