@@ -1,7 +1,7 @@
 // samplv1widget_sample.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -50,9 +50,8 @@
 // samplv1widget_sample -- Custom widget
 
 // Constructor.
-samplv1widget_sample::samplv1widget_sample (
-	QWidget *pParent, Qt::WindowFlags wflags )
-	: QFrame(pParent, wflags), m_pSamplUi(nullptr),
+samplv1widget_sample::samplv1widget_sample ( QWidget *pParent )
+	: QFrame(pParent), m_pSamplUi(nullptr),
 		m_pSample(nullptr), m_iChannels(0), m_ppPolyg(nullptr)
 {
 	QFrame::setMouseTracking(true);
@@ -856,7 +855,7 @@ void samplv1widget_sample::openSample (void)
 	const QString& sTitle  = tr("Open Sample");
 	const QString& sFilter = s_filters.join(";;");
 	QWidget *pParentWidget = nullptr;
-	QFileDialog::Options options = 0;
+	QFileDialog::Options options;
 	if (pConfig->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
 		pParentWidget = QWidget::window();
